import { Handlers, PageProps } from "$fresh/server.ts";
import { MainLayout } from "@components/layouts/main.tsx";
import { Article, getArticle } from "@lib/resource/articles.ts";
import { RecipeHero } from "@components/RecipeHero.tsx";
import { KMenu } from "@islands/KMenu.tsx";
import { YoutubePlayer } from "@components/Youtube.tsx";
import { HashTags } from "@components/HashTags.tsx";
import { isYoutubeLink } from "@lib/string.ts";
import { renderMarkdown } from "@lib/documents.ts";
import { RedirectSearchHandler } from "@islands/Search.tsx";

export const handler: Handlers<Article | null> = {
  async GET(_, ctx) {
    const article = await getArticle(ctx.params.name);
    return ctx.render({ article, session: ctx.state.session });
  },
};

export default function Greet(
  props: PageProps<{ article: Article; session: Record<string, string> }>,
) {
  const { article, session } = props.data;

  const { author = "", date = "" } = article.meta;

  const content = renderMarkdown(article.content);

  return (
    <MainLayout
      url={props.url}
      title={`Article > ${article.name}`}
      context={article}
    >
      <RedirectSearchHandler />
      <KMenu type="main" context={{ type: "article" }} />
      <RecipeHero
        data={article}
        subline={[
          author && {
            title: author,
            href: `/?q=${encodeURIComponent(author)}`,
          },
          date.toString(),
        ]}
        editLink={session
          ? `https://notes.max-richter.dev/Media/articles/${article.id}`
          : ""}
        backlink="/articles"
      />
      {article.tags.length > 0 && (
        <>
          <br />
          <HashTags tags={article.tags} />
        </>
      )}

      <div class="px-8 text-white mt-10">
        {isYoutubeLink(article.meta.link) && (
          <YoutubePlayer link={article.meta.link} />
        )}
        <pre
          class="whitespace-break-spaces markdown-body"
          data-color-mode="dark"
          data-dark-theme="dark"
          dangerouslySetInnerHTML={{ __html: content || "" }}
        >
          {content||""}
        </pre>
      </div>
    </MainLayout>
  );
}
