import { Handlers, PageProps } from "$fresh/server.ts";
import { MainLayout } from "@components/layouts/main.tsx";
import { getAllMovies, Movie } from "@lib/resource/movies.ts";
import { ResourceCard } from "@components/Card.tsx";
import { Grid } from "@components/Grid.tsx";
import { IconArrowLeft } from "@components/icons.tsx";
import { KMenu } from "@islands/KMenu.tsx";
import { RedirectSearchHandler } from "@islands/Search.tsx";
import { parseResourceUrl, searchResource } from "@lib/search.ts";
import { SearchResult } from "@lib/types.ts";

export const handler: Handlers<
  { movies: Movie[] | null; searchResults?: SearchResult }
> = {
  async GET(req, ctx) {
    const movies = await getAllMovies();
    const searchParams = parseResourceUrl(req.url);
    const searchResults = searchParams &&
      await searchResource({ ...searchParams, type: "movie" });
    return ctx.render({ movies, searchResults });
  },
};

export default function Greet(
  props: PageProps<{ movies: Movie[] | null; searchResults: SearchResult }>,
) {
  const { movies, searchResults } = props.data;

  return (
    <MainLayout
      url={props.url}
      title="Movies"
      context={{ type: "movie" }}
      searchResults={searchResults}
    >
      <RedirectSearchHandler />
      <KMenu type="main" context={{ type: "movie" }} />
      <header class="flex gap-4 items-center mb-5 md:hidden">
        <a
          class="px-4 ml-4 py-2 bg-gray-300 text-gray-800 rounded-lg flex items-center gap-1"
          href="/"
        >
          <IconArrowLeft class="w-5 h-5" />
          Back
        </a>

        <h3 class="text-2xl text-white font-light">🍿 Movies</h3>
      </header>
      <Grid>
        {movies?.map((doc) => {
          return <ResourceCard res={doc} />;
        })}
      </Grid>
    </MainLayout>
  );
}
